# Generated by Django 4.2.1 on 2023-05-15 08:19

import ckeditor_uploader.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Human',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('position', models.SmallIntegerField(default=1, help_text='In which position is person listed', unique=True)),
                ('image', models.ImageField(default='humansImages/default.webp', upload_to='humansImages/', verbose_name='Person image')),
                ('name', models.TextField(null=True)),
                ('role', models.TextField(help_text='Role inside of the organization', null=True)),
                ('shortDescription', ckeditor_uploader.fields.RichTextUploadingField(blank=True, null=True)),
                ('description', ckeditor_uploader.fields.RichTextUploadingField(blank=True, null=True)),
                ('isPublished', models.BooleanField(default=False, help_text='After setting Yes, person wil be visible for all users, after setting No - for admins only ', null=True, verbose_name='Published')),
                ('customSlug', models.TextField(help_text='Slug that will lead to persons page, i.e. yourdomain.com/team/<slug>/', unique=True, verbose_name='Custom slug')),
                ('websiteUrl', models.URLField(blank=True, null=True)),
                ('twitterUrl', models.URLField(blank=True, null=True)),
                ('linkedInUrl', models.URLField(blank=True, null=True)),
            ],
            options={
                'verbose_name_plural': 'Humans',
            },
        ),
    ]
