# Generated by Django 4.2.5 on 2023-09-12 10:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('humans', '0002_human_metadescription'),
    ]

    operations = [
        migrations.AlterField(
            model_name='human',
            name='metaDescription',
            field=models.TextField(blank=True, null=True),
        ),
    ]
